NativePopupAd class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
BuildContext context, {NativeAdType type = NativeAdType.medium, bool barrierDismissible = true, Widget? title, Widget? closeIcon, EdgeInsets padding = const EdgeInsets.all(16), BorderRadius borderRadius = const BorderRadius.all(Radius.circular(20))}) → Future< void>